package
Version:
v0.0.0-...-80248e1
Opens a new window with list of versions in this module.
Published: Dec 17, 2025
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
CreateDirectory 创建目录
path: 目录路径
func NewOptions() *options
NewOptions 创建选项
PathFileExists 判断文件是否存在
pathFile: 文件路径
return: 存在-true, 不存在-false
WriteFile 写文件,可选择覆盖或者追加
pathFile: 文件路径
data: 写入的数据
opts: 覆盖写入, 追加写入, 默认覆盖写入
Source Files
¶
Click to show internal directories.
Click to hide internal directories.